@@ -4,12 +4,17 @@ from sqlbatis import (
     with_connection,
     with_transaction,
     get_connection,
+    close,
+    Driver,
+    sql,
+    mapper,
     init_snowflake,
-    get_snowflake_id
+    get_snowflake_id,
+    init_db as _init_db
 )
 
 from .sql_mapper import sql, mapper
-from sqlbatis.engine import PostgresEngine
+from sqlexec import Dialect, Engine
 
 def init_db(*args, **kwargs):
     """
@@ -24,15 +29,13 @@ def init_db(*args, **kwargs):
 
     Addition parameters:
     :param mapper_path: str, path of mapper files
-    :param driver=None: str, import driver, 'import pymysql'
+    :param driver=None: str|Driver, import driver, 'import pymysql'
     :param pool_size=0: int, default 0, size of connection pool
     :param show_sql=False: bool,  if True, print sql
     :param debug=False: bool, if True, print debug context
-    :param trans_placeholder=True: bool, if True, sql placeholder '?' --> '%s'
 
     Other parameters of connection pool refer to DBUtils: https://webwareforpython.github.io/DBUtils/main.html#pooleddb-pooled-db
     """
-    from sqlbatis import init_db as supper_init_db
 
-    PostgresEngine.init()
-    supper_init_db(*args, **kwargs)
+    Dialect.init(Engine.POSTGRESQL)
+    _init_db(*args, **kwargs)
